# anigmo: Artificial Intelligence in abstract logic games

[`anigmo`](https://github.com/cwoebker/anigmo) is an AI library that can be used to play abstract logic games.

[![Status unavailable](https://secure.travis-ci.org/cwoebker/anigmo.png?branch=master)](http://travis-ci.org/cwoebker/anigmo)

---

## Naming ##

**Why anigmo?**

Because.

## What is this? ##

A library.

## Installation

It's as simple as that:

`$ pip install anigmo` (This doesn't work yet)

## Usage

Go look at the code for now.

## Features ##

Everything you ever wished for.

## Documentation ##

If you actually want to learn about this library check out the [documentation](http://cwoebker.github.io/anigmo)

## Contribute

[Fork and contribute!](http://github.com/cwoebker/anigmo)

---

For questions and suggestions, feel free to shoot me an email <me@cwoebker.com>

Follow [@cwoebker](http://twitter.com/cwoebker)

---

Copyright (c) 2013, Cecil Woebker.
License: BSD (see LICENSE for details)
